@@ -5,8 +5,6 @@
 #ifndef _POP_DATABASE_H
 #define _POP_DATABASE_H
 
-#include "md5/md5.h"
-
 #include "params.h"
 
 /*
@@ -25,21 +23,25 @@
 
 struct db_message {
 	struct db_message *next;
-	long size;			/* Size as reported via POP */
-	int flags;			/* MSG_* flags defined above */
-	long raw_offset, raw_size;	/* Raw, with the "From " line */
-	long data_offset, data_size;	/* Just the message itself */
+	unsigned long size;		/* Size as reported via POP */
+	unsigned int flags;		/* MSG_* flags defined above */
+	unsigned long raw_offset;	/* Raw, with the "From " line */
+	unsigned long raw_size;
+	unsigned long data_offset;	/* Just the message itself */
+	unsigned long data_size;
 	unsigned char hash[16];		/* MD5 hash, to be used for UIDL */
 };
 
 struct db_main {
 	struct db_message *head, *tail;	/* Messages in a linked list */
 	struct db_message **array;	/* Direct access to messages */
-	int total_count, visible_count;	/* Total and not DELEted counts */
-	long total_size, visible_size;	/* To be reported via POP */
-	int flags;			/* DB_* flags defined above */
+	unsigned int total_count;	/* All loaded messages and */
+	unsigned int visible_count;	/* just those not DELEted */
+	unsigned long total_size;	/* Their cumulative sizes, */
+	unsigned long visible_size;	/* to be reported via POP */
+	unsigned int flags;		/* DB_* flags defined above */
 #if POP_SUPPORT_LAST
-	int last;			/* Last message touched */
+	unsigned int last;		/* Last message touched */
 #endif
 };
 
